GetMethods extension

on

Methods

currentUserFollows(List<String> ids, String type) Future<List<bool>>

Available on SpotifyApi, provided by the GetMethods extension

Checks if the current user follows given artists or users.
currentUserFollowsPlaylist(String playlistId) Future<bool>

Available on SpotifyApi, provided by the GetMethods extension

Checks if the current user follows a given playlist.
getAudioAnalysis(String trackId) Future<AudioAnalysis>

Available on SpotifyApi, provided by the GetMethods extension

Gets detailed audio analysis for a given track.
getAvailableGenreSeeds() Future<List<String>>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves the list of available genre seeds for recommendations.
getAvailableMarkets() Future<List<String>>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves the list of available Spotify markets.
getCurrentUser() Future<User>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves the current user's profile.
getFollowedArtists({int limit = 20, String? after}) Future<List<User>>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves the list of artists followed by the current user.
getPlaylistTracks({required String playlistId, int offset = 0, int limit = 100}) Future<List<Track>>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves tracks from a given playlist.
getRecommendations({List<String>? seedTracks, List<String>? seedArtists, List<String>? seedGenres, Map<String, dynamic>? audioFeatures, String? market, int limit = 20}) Future<List<Track>>

Available on SpotifyApi, provided by the GetMethods extension

Gets track recommendations based on seeds and optional audio features.
getTrackById(String trackId) Future<Track>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves details for a specific track by its ID.
getUserById(String userId) Future<User>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves a user profile by user ID.
getUserPlaylists({int offset = 0, int limit = 50}) Future<List<Playlist>>

Available on SpotifyApi, provided by the GetMethods extension

Retrieves playlists of the current user.
getUserTopItems<T>({required String type, String timeRange = 'medium_term', int limit = 20, required T fromJson(Map<String, dynamic>)}) Future<List<T>>

Available on SpotifyApi, provided by the GetMethods extension

Gets the current user's top tracks or artists.
isTrackInUserLikedTracks(String trackId) Future<bool>

Available on SpotifyApi, provided by the GetMethods extension

Returns true if the current user has liked a specific track. otherwise, returns false.

Available on SpotifyApi, provided by the GetMethods extension

Performs a search across Spotify content.