PostMethods extension

on

Methods

addTracksToPlaylist(String playlistId, List<String> trackUris, {int? position}) Future<void>

Available on SpotifyApi, provided by the PostMethods extension

Adds a list of track URIs to a playlist identified by playlistId. If position is provided, tracks are inserted at that position.
createPlaylist(String userId, String name, {String? description, bool? isPublic, bool? collaborative}) Future<Playlist>

Available on SpotifyApi, provided by the PostMethods extension

Creates a new playlist for a user with userId and name. Optional parameters: description, isPublic, collaborative. Returns the created Playlist.
followArtistsOrUsers(List<String> ids, String type) Future<void>

Available on SpotifyApi, provided by the PostMethods extension

Follows a list of users or artists. type must be either 'artist' or 'user'.
followPlaylist(String playlistId) Future<void>

Available on SpotifyApi, provided by the PostMethods extension

Follows a playlist specified by playlistId.
saveAlbums(List<String> albumIds) Future<void>

Available on SpotifyApi, provided by the PostMethods extension

Saves a list of album IDs to the user's library.
saveTracks(List<String> trackIds) Future<void>

Available on SpotifyApi, provided by the PostMethods extension

Saves a list of track IDs to the user's library.