PutMethods extension

on

Methods

followArtistsOrUsers(List<String> ids, String type) Future<void>

Available on SpotifyApi, provided by the PutMethods extension

Follows users or artists by ids. type must be either 'artist' or 'user'.
followPlaylist(String playlistId, {bool? isPublic}) Future<void>

Available on SpotifyApi, provided by the PutMethods extension

Follows a playlist identified by playlistId. Optional isPublic sets whether the follow is public.
saveAlbums(List<String> albumIds) Future<void>

Available on SpotifyApi, provided by the PutMethods extension

Saves a list of album IDs to the user's library.
saveTracks(List<String> trackIds) Future<void>

Available on SpotifyApi, provided by the PutMethods extension

Saves a list of track IDs to the user's library.
updatePlaylistDetails(String playlistId, {String? name, String? description, bool? isPublic, bool? collaborative}) Future<void>

Available on SpotifyApi, provided by the PutMethods extension

Updates details of an existing playlist identified by playlistId. Optional parameters can update the name, description, visibility, and collaboration status.