Artist class

Constructors

Artist({required String id, required String name, List<String>? genres, required int popularity, required int followers, required String spotifyUrl, String? href, String? type, String? uri, required List<String> images})
Artist.fromJson(Map<String, dynamic> json)
factory

Properties

followers int
final
genres List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
id String
final
images List<String>
final
name String
final
popularity int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spotifyUrl String
final
type String?
final
uri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited