Meta class

Constructors

Meta({required String analyzerVersion, required String platform, required String detailedStatus, required int statusCode, required String timestamp, required int analysisTime, required String inputProcess})
Meta.fromJson(Map<String, dynamic> json)
factory

Properties

analysisTime int
final
analyzerVersion String
final
detailedStatus String
final
hashCode int
The hash code for this object.
no setterinherited
inputProcess String
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
timestamp String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited