Section class
Constructors
- Section({required double start, required double duration, required double confidence, required double loudness, required double loudnessStart, required double loudnessMax, required double loudnessMaxTime, required double tempo, required double tempoConfidence, required int key, required double keyConfidence, required int mode, required double modeConfidence, required int timeSignature, required double timeSignatureConfidence})
-
Section.fromJson(Map<
String, dynamic> json) -
factory
Properties
- confidence → double
-
final
- duration → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → int
-
final
- keyConfidence → double
-
final
- loudness → double
-
final
- loudnessMax → double
-
final
- loudnessMaxTime → double
-
final
- loudnessStart → double
-
final
- mode → int
-
final
- modeConfidence → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → double
-
final
- tempo → double
-
final
- tempoConfidence → double
-
final
- timeSignature → int
-
final
- timeSignatureConfidence → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited