SegmentDetailed class

Constructors

SegmentDetailed({required double start, required double duration, required double confidence, required double loudnessStart, required double loudnessMax, required double loudnessMaxTime, required double loudnessEnd, required List<double> pitches, required List<double> timbre})
SegmentDetailed.fromJson(Map<String, dynamic> json)
factory

Properties

confidence double
final
duration double
final
hashCode int
The hash code for this object.
no setterinherited
loudnessEnd double
final
loudnessMax double
final
loudnessMaxTime double
final
loudnessStart double
final
pitches List<double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start double
final
timbre List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited