TrackInfo class
Constructors
- TrackInfo({required double duration, required double sampleMd5, required double offsetSeconds, required int windowSeconds, required int analysisSampleRate, required int analysisChannels, required int endOfFadeIn, required int startOfFadeOut, required double loudness, required double tempo, required double tempoConfidence, required int timeSignature, required double timeSignatureConfidence, required int key, required double keyConfidence, required int mode, required double modeConfidence, required String codestring, required int codeVersion, required String echoprintstring, required int echoprintVersion, required String synchstring, required int synchVersion, required String rhythmstring, required int rhythmVersion})
-
TrackInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- analysisChannels → int
-
final
- analysisSampleRate → int
-
final
- codestring → String
-
final
- codeVersion → int
-
final
- duration → double
-
final
- echoprintstring → String
-
final
- echoprintVersion → int
-
final
- endOfFadeIn → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → int
-
final
- keyConfidence → double
-
final
- loudness → double
-
final
- mode → int
-
final
- modeConfidence → double
-
final
- offsetSeconds → double
-
final
- rhythmstring → String
-
final
- rhythmVersion → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleMd5 → double
-
final
- startOfFadeOut → int
-
final
- synchstring → String
-
final
- synchVersion → int
-
final
- tempo → double
-
final
- tempoConfidence → double
-
final
- timeSignature → int
-
final
- timeSignatureConfidence → double
-
final
- windowSeconds → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited