Device class

Constructors

Device({required String id, required String name, required bool isActive, required bool isRestricted, required String type, required int volumePercent})
Device.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isActive bool
final
isRestricted bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
volumePercent int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited