ExternalIds class

Constructors

ExternalIds({String? isrc, String? ean, String? upc})
ExternalIds.fromJson(Map<String, dynamic> json)
factory

Properties

ean String?
final
hashCode int
The hash code for this object.
no setterinherited
isrc String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upc String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited