PlaybackState class

Constructors

PlaybackState({Track? item, required bool isPlaying, required int progressMs, String? repeatState, required bool shuffleState, Device? device})
PlaybackState.fromJson(Map<String, dynamic> json)
factory

Properties

device Device?
final
hashCode int
The hash code for this object.
no setterinherited
isPlaying bool
final
item Track?
final
progressMs int
final
repeatState String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shuffleState bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited