User class

Constructors

User({required String id, required String displayName, String? email, int? followers, required String spotifyUrl, required List<String> images})
User.fromJson(Map<String, dynamic> json)
factory

Properties

displayName String
final
email String?
final
followers int?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
images List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spotifyUrl String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited