SpotifyAuth class
Handles Spotify authentication using Authorization Code Flow with PKCE.
- Implementers
Constructors
Properties
- accessToken → String?
-
Currently active access token.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
String clientId, String redirectUri, [List< String> ? scopes]) → Future<void> -
clearToken(
) → Future< void> - Clears tokens from local storage and memory.
-
dispose(
) → void - Cancels any ongoing URI link stream.
-
isTokenValid(
) → Future< bool> - Checks if the stored access token is still valid.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshAccessToken(
) → Future< void> - Refreshes the access token using the stored refresh token.
-
toString(
) → String -
A string representation of this object.
inherited
-
tryRestoreToken(
) → Future< bool> - Attempts to restore saved tokens from local storage.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited