Album class
Constructors
-
Album({required String id, required String name, required String albumType, List<
String> ? availableMarkets, required List<Artist> artists, required String releaseDate, required String releaseDatePrecision, required int totalTracks, required String spotifyUrl, String? href, String? type, String? uri, required List<String> images}) -
Album.fromJson(Map<
String, dynamic> json) -
factory
Properties
- albumType → String
-
final
-
artists
→ List<
Artist> -
final
-
availableMarkets
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String?
-
final
- id → String
-
final
-
images
→ List<
String> -
final
- name → String
-
final
- releaseDate → String
-
final
- releaseDatePrecision → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spotifyUrl → String
-
final
- totalTracks → int
-
final
- type → String?
-
final
- uri → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited