Artist class
Constructors
-
Artist({required String id, required String name, List<String>? genres, required int popularity, required int followers, required String spotifyUrl, String? href, String? type, String? uri, required List<String> images})
-
-
Artist.fromJson(Map<String, dynamic> json)
-
factory
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited