AudioAnalysis class
Constructors
-
AudioAnalysis({required Meta meta, required TrackInfo track, required List<
TimeInterval> bars, required List<TimeInterval> beats, required List<Section> sections, required List<SegmentDetailed> segmentsDetailed, required List<TimeInterval> tatums}) -
AudioAnalysis.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
bars
→ List<
TimeInterval> -
final
-
beats
→ List<
TimeInterval> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → Meta
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
Section> -
final
-
segmentsDetailed
→ List<
SegmentDetailed> -
final
-
tatums
→ List<
TimeInterval> -
final
- track → TrackInfo
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited