AudioFeatures class
Constructors
- AudioFeatures({required String id, required double danceability, required double energy, required int key, required double loudness, required int mode, required double speechiness, required double acousticness, required double instrumentalness, required double liveness, required double valence, required double tempo, required int durationMs, required int timeSignature, required String type, required String uri, required String trackHref, required String analysisUrl})
-
AudioFeatures.fromJson(Map<
String, dynamic> json) -
factory
Properties
- acousticness → double
-
final
- analysisUrl → String
-
final
- danceability → double
-
final
- durationMs → int
-
final
- energy → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- instrumentalness → double
-
final
- key → int
-
final
- liveness → double
-
final
- loudness → double
-
final
- mode → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speechiness → double
-
final
- tempo → double
-
final
- timeSignature → int
-
final
- trackHref → String
-
final
- type → String
-
final
- uri → String
-
final
- valence → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited