Playlist class
Constructors
-
Playlist({required String id, required String name, required String description, required bool isPublic, required bool isCollaborative, required String href, required String uri, required String spotifyUrl, required int trackCount, required User owner, required List<
String> images}) -
Playlist.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String
-
final
- id → String
-
final
-
images
→ List<
String> -
final
- isCollaborative → bool
-
final
- isPublic → bool
-
final
- name → String
-
final
- owner → User
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spotifyUrl → String
-
final
- trackCount → int
-
final
- uri → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited