Track class
Constructors
-
Track({required String id, required String name, required int durationMs, required bool isExplicit, required bool isPlayable, required int popularity, String? previewUrl, required int discNumber, required int trackNumber, required bool isLocal, required String spotifyUrl, required List<
Artist> artists, required Album album, List<String> ? availableMarkets, dynamic externalIds, required List<String> images}) -
Track.fromJson(Map<
String, dynamic> json) -
factory
Properties
- album → Album
-
final
-
artists
→ List<
Artist> -
final
-
availableMarkets
→ List<
String> ? -
final
- discNumber → int
-
final
- durationMs → int
-
final
- externalIds → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
images
→ List<
String> -
final
- isExplicit → bool
-
final
- isLocal → bool
-
final
- isPlayable → bool
-
final
- name → String
-
final
- popularity → int
-
final
- previewUrl → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spotifyUrl → String
-
final
- trackNumber → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited